/**
 * Copyright 2007-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.archive.api;

/**
 * Interface of Archive Manager.
 * @author Francois Fornaciari
 */
public interface IArchiveManager {

    /**
     * Adds the given factory on this manager. It will look the generic info
     * used by this class to find the class object managed by this factory.
     * @param factory the factory to add.
     */
    void addFactory(final IArchiveFactory<?> factory);

    /**
     * Creates an EZBArchive implementation object for the given object.
     * @param o object to wrap into an EZBArchive.
     * @return the created archive.
     */
    IArchive getArchive(final Object o);

    /**
     * Removes the given factory on this manager. It will look the generic info
     * used by this class to find the class object managed by this factory.
     * @param factory the factory to remove.
     */
    void removeFactory(final IArchiveFactory<?> factory);
}
